@@ -1,8 +1,8 @@
 `XSEC.drive` <-
-  function(MOD, x1, y1, x2, y2 , zmax=100, COL=TOMO.colors(100), LIM=NULL, STA=NULL, TOP=NULL, STDLAB=c("DONE", "QUIT"))
+  function(MOD, x1, y1, x2, y2 , zmax=100, COL=tomo.colors(100), LIM=NULL, STA=NULL, TOP=NULL, STDLAB=c("DONE", "QUIT"))
 {
 
-  if(missing(COL)) { COL=TOMO.colors(100) }
+  if(missing(COL)) { COL=tomo.colors(100) }
   if(missing(LIM)) { LIM=NULL }
   if(missing(STA)) { STA=NULL }
   if(missing(TOP)) { TOP=NULL }
